@@ -1,15 +1,11 @@
 '''
 A widget for editing EnviConfig options.
 '''
-try:
-    from PyQt4 import QtCore, QtGui
-    from PyQt4.QtGui import *
-except:
-    from PyQt5 import QtCore, QtGui, QtWidgets
-    from PyQt5.QtWidgets import *
+from PyQt5 import QtCore, QtGui, QtWidgets
+from PyQt5.QtWidgets import *
+
 
 class EnviConfigOption:
-
     def __init__(self, config, name, value):
         self.econfig = config
         self.ename = name
@@ -19,23 +15,23 @@ class EnviConfigOption:
         self.evalue = evalue
         self.econfig[self.ename] = evalue
 
-class EnviConfigBool(EnviConfigOption,QCheckBox):
 
+class EnviConfigBool(EnviConfigOption,QCheckBox):
     def __init__(self, config, name, value, parent=None):
         QCheckBox.__init__(self, parent=parent)
         EnviConfigOption.__init__(self, config, name, value)
-        self.toggled.connect( self.setEnviValue )
+        self.toggled.connect(self.setEnviValue)
         self.setChecked(value)
 
     def parseEnviValue(self):
-        self.setEnviValue( self.isChecked() )
+        self.setEnviValue(self.isChecked())
+
 
 class EnviConfigInt(EnviConfigOption,QLineEdit):
-
     def __init__(self, config, name, value, parent=None):
         QLineEdit.__init__(self, parent=parent)
         EnviConfigOption.__init__(self, config, name, value)
-        self.editingFinished.connect( self.parseEnviValue )
+        self.editingFinished.connect(self.parseEnviValue)
 
         valstr = str(value)
         if value > 1024:
@@ -45,24 +41,25 @@ class EnviConfigInt(EnviConfigOption,QLineEdit):
     def parseEnviValue(self):
         self.setEnviValue(int(str(self.text()),0))
 
+
 class EnviConfigString(EnviConfigOption,QLineEdit):
     def __init__(self, config, name, value, parent=None):
         QLineEdit.__init__(self, parent=parent)
         EnviConfigOption.__init__(self, config, name, value)
-        self.editingFinished.connect( self.parseEnviValue )
+        self.editingFinished.connect(self.parseEnviValue)
         self.setText(value)
 
     def parseEnviValue(self):
         self.setEnviValue(str(self.text()))
 
+
 cfgtypes = {
-    int:EnviConfigInt,
-    long:EnviConfigInt,
-    str:EnviConfigString,
-    unicode:EnviConfigString,
-    bool:EnviConfigBool,
+    int: EnviConfigInt,
+    str: EnviConfigString,
+    bool: EnviConfigBool,
 }
 
+
 class EnviConfigEditor(QWidget):
 
     def __init__(self, config, parent=None):
@@ -71,7 +68,7 @@ class EnviConfigEditor(QWidget):
 
         lyt = QFormLayout()
 
-        optnames = config.keys()
+        optnames = list(config.keys())
         optnames.sort()
 
         for optname in optnames:
@@ -102,28 +99,3 @@ class EnviConfigTabs(QTabWidget):
         for name,config in configs:
             editor = EnviConfigEditor(config, parent=self)
             self.addTab(editor, name)
-
-if __name__ == '__main__':
-
-    import vqt.main as vq_main
-    import envi.config as e_config
-
-    defaults = {
-        'woot':10,
-        'baz':'faz',
-        'foo':True,
-    }
-
-    docs = {
-        'woot':'The number of woots!',
-        'baz':'Where to look for a baz',
-        'foo':'Should we do foo?',
-    }
-
-    config = e_config.EnviConfig(filename='test.json', defaults=defaults, docs=docs)
-
-    vq_main.startup()
-    widget = EnviConfigEditor( config )
-    widget.show()
-    vq_main.main()
-
