@@ -1,12 +1,7 @@
 import binascii
 
-
-try:
-    from PyQt5 import QtCore
-    from PyQt5.QtWidgets import *
-except:
-    from PyQt4 import QtCore
-    from PyQt4.QtGui import *
+from PyQt5 import QtCore
+from PyQt5.QtWidgets import *
 
 import envi.memcanvas
 import envi.qt.memdump
