@@ -134,13 +134,13 @@ def seh(vdb, line):
         vdb.vprint("Unknown Thread Id: %d" % tid)
         return
     teb = t.getStruct("ntdll.TEB", tinfo)
-    addr = long(teb.NtTib.ExceptionList)
+    addr = int(teb.NtTib.ExceptionList)
     vdb.vprint("REG        HANDLER")
     while addr != 0xffffffff:
-        #FIXME print out which frame these are in
+        # FIXME print out which frame these are in
         er = t.getStruct("ntdll.EXCEPTION_REGISTRATION_RECORD", addr)
         vdb.vprint("0x%.8x 0x%.8x" % (addr, er.Handler))
-        addr = long(er.Next)
+        addr = int(er.Next)
 
 def safeseh(vdb, line):
     """
@@ -175,7 +175,7 @@ def safeseh(vdb, line):
         vdb.vprint("None...")
 
     else:
-        lnames = libs.keys()
+        lnames = list(libs.keys())
         lnames.sort()
         for name in lnames:
             base = libs.get(name)
@@ -305,7 +305,7 @@ def heaps(vdb, line):
 
         heap = win32heap.Win32Heap(t, uncommit_heap)
         ucrdict = heap.getUCRDict()
-        addrs = ucrdict.keys()
+        addrs = list(ucrdict.keys())
         addrs.sort()
         if len(addrs) == 0:
             vdb.vprint('Heap 0x%.8x has 0 uncommited-ranges!' % uncommit_heap)
@@ -423,7 +423,7 @@ def aslr(vdb, line):
     """
     Determine which PE's in the current process address space
     support Vista's ASLR implementation by the presence of the
-    IMAGE_DLLCHARACTERISTICS_DYNAMIC_BASE (0x0040) bit in the 
+    IMAGE_DLLCHARACTERISTICS_DYNAMIC_BASE (0x0040) bit in the
     DllCharacteristics field of the PE header.
 
     Usage: aslr [libname]
@@ -437,7 +437,7 @@ def aslr(vdb, line):
             return
         showaslr(vdb, base, line)
     else:
-        lnames = libs.keys()
+        lnames = list(libs.keys())
         lnames.sort()
         for name in lnames:
             base = libs.get(name)
@@ -896,7 +896,7 @@ def hooks(vdb, line):
 
             skips = {}
             # Get relocations for skipping
-            r = range( t.getPointerSize() )
+            r = list(range( t.getPointerSize() ))
             for relrva, reltype in pobj.getRelocations():
                 for i in r:
                     skips[base+relrva+i] = True
@@ -933,7 +933,7 @@ def hooks(vdb, line):
                         sym = vdb.symobj.getSymByAddr(difva, exact=False)
                         if sym is not None:
                             vdb.canvas.addText(' ')
-                            vdb.canvas.addVaText('%s + %d' % (repr(sym),difva-long(sym)), difva)
+                            vdb.canvas.addVaText('%s + %d' % (repr(sym),difva-int(sym)), difva)
                         vdb.canvas.addText('\n')
 
     if not found:
