@@ -15,11 +15,11 @@ VWE_DELSEGMENT      = 4 # FIXME IMPLEMENT
 VWE_ADDRELOC        = 5 # (va,rtype)
 VWE_DELRELOC        = 6 # # FIXME IMPLEMENT
 
-VWE_ADDMODULE       = 7 # DEPRICATED
-VWE_DELMODULE       = 8 # DEPRICATED
+VWE_ADDMODULE       = 7 # DEPRECATED
+VWE_DELMODULE       = 8 # DEPRECATED
 
-VWE_ADDFMODULE      = 9  # DEPRICATED
-VWE_DELFMODULE      = 10 # DEPRICATED
+VWE_ADDFMODULE      = 9  # DEPRECATED
+VWE_DELFMODULE      = 10 # DEPRECATED
 
 VWE_ADDFUNCTION     = 11 # (va, meta)
 VWE_DELFUNCTION     = 12 # va
