@@ -4,7 +4,8 @@ import itertools
 import envi
 import envi.exc as e_exc
 import envi.bits as e_bits
-import envi.memory as e_mem
+import envi.common as e_common
+import envi.memory as e_memory
 
 import visgraph.pathcore as vg_path
 
@@ -31,22 +32,100 @@ class WorkspaceEmulator:
 
     taintregs = []
 
-    def __init__(self, vw, logwrite=False, logread=False):
+    def __init__(self, vw, **kwargs):
+        '''
+        Base Emulator Class that other, more platform specific emulators inherit from/mixin.
 
+        Since there's a fair number of knobs that can be turned on the emulator and several
+        descendants of the base WorkspaceEmulator, these kwargs apply not only to the base class,
+        but most children like the ArmWorkspaceEmulator and any others that live in vivisect/impemu/platarm/
+
+        Current Keyword Arguments:
+        * logwrite
+            - Type: Boolean
+            - Default: False
+            - Desc: Enable tracking of all memory writes along the exeuction path. Any results are stored on
+                    the path object as a node property at WorkspaceEmulator.curpath
+        * logread
+            - Type: Boolean
+            - Default: False
+            - Desc: Enable tracking of all memory writes along the exeuction path. Any results are stored on
+                    the path object as a node property at WorkspaceEmulator.curpath
+        * safemem
+            - Type: Boolean
+            - Default: True
+            - Desc: Since we're not a real CPU, and since we also do a lot of partial emulation, we can't
+                    always be sure we're reading from/writing to a valid memory location. So if safemem is
+                    set to True, this enables several addition safety rails in the emulator in terms of
+                    where memory can be read from/written to, and where execution flow can be read from
+        * funconly
+            - Type: Boolean
+            - Default: True
+            - Desc: When emulating, by default when a call/branch to other function instruction happens,
+                    instead of emulating down into the called function, we push the return value onto our
+                    emulated stack, and then using the detected calling convention of the subfunction, try
+                    and detect where to go. Set this value to False to instead, when a call instruction is
+                    hit, emulate down into that subfunction.
+                    Please note that since there's not "Stop when you hit X" condition, disabling this
+                    can have a massive impact on performance.
+        * strictops
+            - Type: Boolean
+            - Default: True
+            - Desc: Due to development time constraints, or plain inability to emulate, not all instructions
+                    on every platform we support is emulated. It may be properly decoded, but if it's not
+                    not supported, by default when emulating, the emulator will bail out of the paths that
+                    contain the unsupported instruction. Set this parameter to false if you want to continue
+                    down those paths even when encountering unsupported instructions
+                    Please note that since any possible effects the unsupported instruction are not
+                    propagated, any possible flags or execution state are most likely misaligned from what
+                    a real CPU might experience.
+        * loglevel
+            - Type: Integer
+            - Default: 30 (Corresponds to logging.WARNING)
+            - Desc: Because we do partial emulation for several of our heuristic passes like isProbablyCode,
+                    but also full emulation for several other analysis passes, there are several logging
+                    calls that are erroneous under the heuristic passes and typically we want those silenced
+                    under the heuristic passes only.
+        * taintbase
+            - Type: Integer
+            - Default: 0x4156000F
+            - Desc: This option affects where we start taint values, which are how we determine what has been
+                    written where, what's been called, what values have been edited where, etc.
+                    WARNING: Like taintbyte below, while you can modify this value to suit your needs, you
+                    should review how the emulator works before modifying this value, as this can directly
+                    impact various forms of analysis such as calling convention detection, what values get
+                    associated with what API calls, and more.
+        * taintbyte
+            - Type: A python byte object of length 1
+            - Default: b'a'
+            - Desc: So when the emulator attempts to read memory, and it's in a location that has yet to be
+                    defined (because we're missing the full context of execution inside a real process) or
+                    isn't technically considered okay to read from (see probeMemory in envi/memory.py for
+                    what we consider to be "okay"), but if we have _safe_mem turned on, we instead return a
+                    mocked value that's just the taint bytes, but repeated a number of times equal to the
+                    desired read size. Otherwise, we attempt to drop into the base memory object's readMemory
+                    to see if there is anything there.
+                    WARNING: While this value is configurable, changing this value without knowing what you're
+                    doing can result in undesirable effects (such as infinite recursion when trying to repr
+                    taint values), so change this value with care.
+        '''
         self.vw = vw
-        self.funcva = None # Set if using runFunction
+        # Set down below in runFunction
+        self.funcva = None
         self.emustop = False
 
         self.hooks = {}
         self.taints = {}
-        self.taintva = itertools.count(0x4156000F, 0x2000)
+        base = int(kwargs.get('taintbase', 0x4156000F))
+        self.taintva = itertools.count(base, 0x2000)
         self.taintoffset = 0x1000
         self.taintmask = 0xffffe000
+        self.taintbyte = kwargs.get('taintbyte', b'a')
         self.taintrepr = {}
 
         self.uninit_use = {}
-        self.logwrite = logwrite
-        self.logread = logread
+        self.logwrite = kwargs.get('logwrite', False)
+        self.logread = kwargs.get('logread', False)
         self.path = self.newCodePathNode()
         self.curpath = self.path
         self.op = None
@@ -55,10 +134,15 @@ class WorkspaceEmulator:
         self.psize = self.getPointerSize()
 
         # Possibly need an "options" API?
-        self._safe_mem = True   # Should we be forgiving about memory accesses?
-        self._func_only = True  # is this emulator meant to stay in one function scope?
-
-        self.strictops = True   # should we bail on emulation if unsupported instruction encountered
+        # Should we be forgiving about memory accesses?
+        self._safe_mem = kwargs.get("safemem", True)
+        # Is this emulator meant to stay in one function scope?
+        self._func_only = kwargs.get("funconly", True)
+        # Should we bail on emulation if unsupported instruction encountered?
+        self.strictops = kwargs.get('strictops', True)
+        # So this has nothing to do with the above logwrite/logread
+        # But default to being as permissive as the top level logger allows
+        self._log_level = kwargs.get('loglevel', logging.WARNING)
 
         # Map in all the memory associated with the workspace
         for va, size, perms, fname in vw.getMemoryMaps():
@@ -66,8 +150,7 @@ class WorkspaceEmulator:
             self.addMemoryMap(va, perms, fname, bytes)
 
         for regidx in self.taintregs:
-            rname = self.getRegisterName(regidx)
-            regval = self.setVivTaint( 'uninitreg', regidx )
+            regval = self.setVivTaint('uninitreg', regidx)
             self.setRegister(regidx, regval)
 
         for name in dir(self):
@@ -75,7 +158,7 @@ class WorkspaceEmulator:
             if val is None:
                 continue
 
-            impname = getattr(val, '__imphook__',None)
+            impname = getattr(val, '__imphook__', None)
             if impname is None:
                 continue
 
@@ -109,8 +192,8 @@ class WorkspaceEmulator:
 
             # Create some pre-made taints for positive stack indexes
             # NOTE: This is *ugly* for speed....
-            taints = [ self.setVivTaint('funcstack', i * self.psize) for i in range(20) ]
-            taintbytes = ''.join([ e_bits.buildbytes(taint,self.psize) for taint in taints ])
+            taints = [self.setVivTaint('funcstack', i * self.psize) for i in range(20)]
+            taintbytes = b''.join([e_bits.buildbytes(taint, self.psize) for taint in taints])
 
             self.writeMemory(self.stack_pointer, taintbytes)
         else:
@@ -122,8 +205,7 @@ class WorkspaceEmulator:
             new_map_top = self.stack_map_base
             new_map_base = new_map_top - new_map_size
 
-            stack_map = ''.join([struct.pack('<I', new_map_base+(i*4))
-                                    for i in range(new_map_size)])
+            stack_map = b''.join([struct.pack('<I', new_map_base+(i*4)) for i in range(new_map_size)])
 
             self.addMemoryMap(new_map_base, 6, "[stack]", stack_map)
             self.stack_map_base = new_map_base
@@ -205,7 +287,7 @@ class WorkspaceEmulator:
                 # pops, which leads us to say that code path isn't a function since we miss the ret instruction.
                 # So we have here a fix for that. Added some rails so we don'y always just punch it in
                 if self._safe_mem:
-                    if not self.vw.isValidPointer(newaddr) and self.vw.isValidPointer(retn):
+                    if not self.vw.isValidPointer(newaddr) and self.isValidPointer(retn):
                         self.setProgramCounter(retn)
             # no else since we'll emulate into the function
 
@@ -274,7 +356,7 @@ class WorkspaceEmulator:
         if len(blist) > 1:
             for bva, bflags in blist:
                 if bva is None:
-                    logger.warn("Unresolved branch even WITH an emulator?")
+                    logger.warning("Unresolved branch even WITH an emulator?")
                     continue
                 if bva in paths:
                     continue
@@ -298,7 +380,6 @@ class WorkspaceEmulator:
 
         # let's also take into account some of the dynamic branches we may have found
         # like our table pointers
-
         return ret
 
     def stepi(self):
@@ -385,9 +466,10 @@ class WorkspaceEmulator:
                         except v_exc.BadOpBytes as e:
                             logger.debug(str(e))
                             break
+                        except v_exc.BadOutInstruction:
+                            pass
                         except Exception as e:
-                            if not self.getMeta('silent'):
-                                logger.warn("Emulator prehook failed on fva: 0x%x, opva: 0x%x, op: %s, err: %s", funcva, starteip, str(op), str(e))
+                            logger.log(self._log_level, "Emulator prehook failed on fva: 0x%x, opva: 0x%x, op: %s, err: %s", funcva, starteip, str(op), str(e))
 
                         if self.emustop:
                             return
@@ -403,9 +485,10 @@ class WorkspaceEmulator:
                         except v_exc.BadOpBytes as e:
                             logger.debug(str(e))
                             break
+                        except v_exc.BadOutInstruction:
+                            pass
                         except Exception as e:
-                            if not self.getMeta('silent'):
-                                logger.warn("funcva: 0x%x opva: 0x%x:  %r   (%r) (in emumon posthook)", funcva, starteip, op, e)
+                            logger.log(self._log_level, "funcva: 0x%x opva: 0x%x:  %r   (%r) (in emumon posthook)", funcva, starteip, op, e)
 
                         if self.emustop:
                             return
@@ -413,12 +496,6 @@ class WorkspaceEmulator:
                     if self.emustop:
                         return
 
-                    # TODO: hook things like error(...) when they have a param that indicates to 
-                    # exit. Might be a bit hairy since we'll possibly have to fix up codeblocks
-                    if self.vw.isNoReturnVa(endeip):
-                        vg_path.setNodeProp(self.curpath, 'cleanret', False)
-                        break
-
                     # If it wasn't a call, check for branches, if so, add them to
                     # the todo list and go around again...
                     if not iscall:
@@ -435,6 +512,13 @@ class WorkspaceEmulator:
                     if op.iflags & envi.IF_RET:
                         vg_path.setNodeProp(self.curpath, 'cleanret', True)
                         break
+
+                    # TODO: hook things like error(...) when they have a param that indicates to
+                    # exit. Might be a bit hairy since we'll possibly have to fix up codeblocks
+                    if self.vw.isNoReturnVa(op.va):
+                        vg_path.setNodeProp(self.curpath, 'cleanret', False)
+                        break
+
                 except envi.BadOpcode:
                     break
                 except envi.UnsupportedInstruction as e:
@@ -444,6 +528,8 @@ class WorkspaceEmulator:
                     else:
                         logger.debug('runFunction continuing after unsupported instruction: 0x%08x %s', e.op.va, e.op.mnem)
                         self.setProgramCounter(e.op.va + e.op.size)
+                except v_exc.BadOutInstruction:
+                    break
                 except Exception as e:
                     if self.emumon is not None and not isinstance(e, e_exc.BreakpointHit):
                         self.emumon.logAnomaly(self, starteip, str(e))
@@ -487,7 +573,7 @@ class WorkspaceEmulator:
 
     def nextVivTaint(self):
         # One page into the new taint range
-        return self.taintva.next() + self.taintoffset
+        return next(self.taintva) + self.taintoffset
 
     def setVivTaint(self, typename, taint):
         '''
@@ -602,45 +688,45 @@ class WorkspaceEmulator:
         """
         if self.logwrite:
             wlog = vg_path.getNodeProp(self.curpath, 'writelog')
-            wlog.append((self.getProgramCounter(),va,bytes))
+            wlog.append((self.getProgramCounter(), va, bytes))
 
-        self._useVirtAddr( va )
+        self._useVirtAddr(va)
 
         # It's totally ok to write to invalid memory during the
         # emulation pass (as long as safe_mem is true...)
-        probeok = self.probeMemory(va, len(bytes), e_mem.MM_WRITE)
+        probeok = self.probeMemory(va, len(bytes), e_memory.MM_WRITE)
         if self._safe_mem and not probeok:
             return
 
-        return e_mem.MemoryObject.writeMemory(self, va, bytes)
+        return e_memory.MemoryObject.writeMemory(self, va, bytes)
 
     def logUninitRegUse(self, regid):
         self.uninit_use[regid] = True
 
     def getUninitRegUse(self):
-        return self.uninit_use.keys()
+        return list(self.uninit_use.keys())
 
     def readMemory(self, va, size):
         if self.logread:
             rlog = vg_path.getNodeProp(self.curpath, 'readlog')
-            rlog.append((self.getProgramCounter(),va,size))
+            rlog.append((self.getProgramCounter(), va, size))
 
         # If they read an import entry, start a taint...
         loc = self.vw.getLocation(va)
         if loc is not None:
             lva, lsize, ltype, ltinfo = loc
-            if ltype == LOC_IMPORT and lsize == size: # They just read an import.
+            if ltype == LOC_IMPORT and lsize == size:  # They just read an import.
                 ret = self.setVivTaint('import', loc)
                 return e_bits.buildbytes(ret, lsize)
 
         self._useVirtAddr(va)
 
         # Read from the emulator's pages if we havent resolved it yet
-        probeok = self.probeMemory(va, size, e_mem.MM_READ)
+        probeok = self.probeMemory(va, size, e_memory.MM_READ)
         if self._safe_mem and not probeok:
-            return 'A' * size
+            return self.taintbyte * size
 
-        return e_mem.MemoryObject.readMemory(self, va, size)
+        return e_memory.MemoryObject.readMemory(self, va, size)
 
     # Some APIs for telling if pointers are in runtime memory regions
 
@@ -649,7 +735,7 @@ class WorkspaceEmulator:
         If val is a numerical value in the same memory page
         as the un-initialized stack values return True
         """
-        #NOTE: If uninit_stack_byte changes, so must this!
+        # NOTE: If uninit_stack_byte changes, so must this!
         if (val & 0xfffff000) == 0xfefef000:
             return True
         return False
@@ -660,4 +746,3 @@ class WorkspaceEmulator:
     def getStackOffset(self, va):
         if (va & self.stack_map_mask) == self.stack_map_base:
             return va - self.stack_pointer
-
