@@ -187,6 +187,13 @@ def loadElfIntoWorkspace(vw, elf, filename=None, baseaddr=None):
 
     fname = vw.addFile(filename.lower(), baseaddr, md5hash)
     vw.setFileMeta(fname, 'sha256', sha256)
+    vw.setFileMeta(fname, 'relro', getRelRo(elf))
+    vw.setFileMeta(fname, 'canaries', hasStackCanaries(vw))
+    vw.setFileMeta(fname, 'nx', hasNX(elf))
+    vw.setFileMeta(fname, 'pie', hasPIE(elf))
+    vw.setFileMeta(fname, 'rpath', hasRPATH(elf))
+    vw.setFileMeta(fname, 'runpath', hasRUNPATH(elf))
+    vw.setFileMeta(fname, 'stripped', isStripped(elf))
 
     strtabs = {}
     secnames = []
@@ -206,7 +213,7 @@ def loadElfIntoWorkspace(vw, elf, filename=None, baseaddr=None):
             pva = pgm.p_vaddr
             if addbase:
                 pva += baseaddr
-            vw.addMemoryMap(pva, pgm.p_flags & 0x7, fname, bytez)  # FIXME perms
+            vw.addMemoryMap(pva, pgm.p_flags & 0x7, fname, bytez)
         else:
             logger.info('Skipping: %s', pgm)
 
@@ -590,7 +597,7 @@ def applyRelocs(elf, vw, addbase=False, baseaddr=0):
                         vw.makeImport(rlva, "*", dmglname)
                         vw.setComment(rlva, name)
 
-                    elif rtype in (Elf.R_386_32, Elf.R_386_COPY):
+                    elif rtype in (Elf.R_386_32, Elf.R_386_COPY, Elf.R_X86_64_TPOFF64):
                         pass
 
                     else:
@@ -747,6 +754,9 @@ def applyRelocs(elf, vw, addbase=False, baseaddr=0):
                         vw.makeName(rlva, dmglname, makeuniq=True)
                         vw.setComment(rlva, name)
 
+                elif rtype == Elf.R_ARM_COPY:
+                    pass
+
                 else:
                     logger.warning('unknown reloc type: %d %s (at %s)', rtype, name, hex(rlva))
                     logger.info(r.tree())
@@ -787,3 +797,77 @@ def demangle(name):
         logger.debug('failed to demangle name (%r): %r', name, e)
 
     return name
+
+def getRelRo(elf):
+    status = 0
+    for phdr in elf.getPheaders():
+        if phdr.p_type == Elf.PT_GNU_RELRO:
+            status = 1
+            break
+
+    if status:
+        for dyn in elf.getDynamics():
+            if dyn.d_tag == Elf.DT_FLAGS:
+                if dyn.d_value == Elf.DF_BIND_NOW:
+                    status = 2
+
+    return ('NONE', 'Partial', 'FULL')[status]
+
+def hasStackCanaries(vw):
+    '''
+    Check through imports looking for __stack_chk_fail
+    '''
+    for impva, impsz, imptype, impname in vw.getImports():
+        if impname == '*.__stack_chk_fail':
+            return True
+
+    return False
+
+def hasNX(elf):
+    '''
+    Check through ELF Pheaders
+    '''
+    for phdr in elf.getPheaders():
+        if phdr.p_type == Elf.PT_GNU_STACK:
+            if phdr.p_flags == 6:
+                return True
+
+    return False
+
+def hasPIE(elf):
+    '''
+    Check through ELF Headers and Dynamics
+    '''
+    if elf.e_type == Elf.ET_DYN:
+        if elf.dyns.get(Elf.DT_DEBUG) is not None:
+            return True
+        return "DSO"
+
+    return False
+
+def hasRPATH(elf):
+    '''
+    Check through ELF Dynamics
+    '''
+    if elf.dyns.get(Elf.DT_RPATH) is not None:
+        return True
+
+    return False
+
+def hasRUNPATH(elf):
+    '''
+    Check through ELF Dynamics
+    '''
+    if elf.dyns.get(Elf.DT_RUNPATH) is not None:
+        return True
+
+    return False
+
+def isStripped(elf):
+    '''
+    Check through ELF Symbols
+    '''
+    if len(elf.getSymbols()) == 0:
+        return True
+
+    return False
