@@ -1,5 +1,6 @@
 import os
 import sys
+import time
 import unittest
 import subprocess
 
@@ -26,7 +27,15 @@ class VtraceProcessTest(unittest.TestCase):
             self.proc.stdin.write('testmod\n')
             self.proc.stdin.flush()
             self.trace.run()
-        self.proc.wait()
+        try:
+            self.proc.wait(timeout=300)
+        except subprocess.TimeoutExpired:
+            pass
+        finally:
+            # whatever. shoot the process and keep going. Ain't nobody got time for that.
+            self.proc.stdout.close()
+            self.proc.stdin.close()
+            self.proc.kill()
         self.trace.release()
 
     def runProcess(self):
@@ -43,6 +52,7 @@ class VtraceProcessTest(unittest.TestCase):
         self.proc.stdin.write('testmod\n')
         self.proc.stdin.flush()
         self.trace.run()
+        time.sleep(1)
 
         self.assertEqual(self.trace.getMeta('ExitCode'), 33)
 
